"use strict";

var noise_scale = 32.0;

window.onload = function init()
{
  var canvas = document.getElementById("webgl");

  var gl = WebGLUtils.setupWebGL(canvas);
  if (!gl) {
    console.log('Failed to get the rendering context for WebGL');
    return;
  }
  
  // Load shaders and initialize uniforms
  gl.program = initShaders(gl, "vertex-shader", "fragment-shader");
  gl.useProgram(gl.program);
  gl.uniform1f(gl.getUniformLocation(gl.program, "noise_scale"), noise_scale);

  // Initialize scene geometry
  var n = initVertexBuffers(gl, canvas.width/canvas.height);

  render(gl, n);
}

function render(gl, no_of_verts)
{
  gl.clear(gl.COLOR_BUFFER_BIT);
  gl.drawArrays(gl.TRIANGLE_STRIP, 0, no_of_verts);
}

function initVertexBuffers(gl, aspect)
{
  // Create a quad
  var vertices = [
    vec3(-1.0, -1.0, 0.0),
    vec3(1.0, -1.0, 0.0),
    vec3(-1.0, 1.0, 0.0),
    vec3(1.0, 1.0, 0.0)
  ];

  var texcoords = [
    vec2(0.0, 0.0),
    vec2(aspect, 0.0),
    vec2(0.0, 1.0),
    vec2(aspect, 1.0)
  ];

  var vBuffer = gl.createBuffer();
  gl.bindBuffer(gl.ARRAY_BUFFER, vBuffer);
  gl.bufferData(gl.ARRAY_BUFFER, flatten(vertices), gl.STATIC_DRAW);

  var vPosition = gl.getAttribLocation(gl.program, "vPosition");
  gl.vertexAttribPointer(vPosition, 3, gl.FLOAT, false, 0, 0);
  gl.enableVertexAttribArray(vPosition);

  var tBuffer = gl.createBuffer();
  gl.bindBuffer(gl.ARRAY_BUFFER, tBuffer);
  gl.bufferData(gl.ARRAY_BUFFER, flatten(texcoords), gl.STATIC_DRAW);

  var vTexCoord = gl.getAttribLocation(gl.program, "vTexCoord");
  gl.vertexAttribPointer(vTexCoord, 2, gl.FLOAT, false, 0, 0);
  gl.enableVertexAttribArray(vTexCoord);

  return vertices.length;
}
